@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import re
 import fnmatch
 import inspect
@@ -10,8 +7,7 @@ from datetime import date, datetime
 from decimal import Decimal, ROUND_HALF_EVEN
 from email.utils import formatdate
 
-from six import iteritems, itervalues, text_type, string_types
-from six.moves.urllib.parse import urlparse, urlunparse
+from urllib.parse import urlparse, urlunparse
 
 from flask import url_for, request
 from werkzeug.utils import cached_property
@@ -59,7 +55,7 @@ class MarshallingError(RestError):
     def __init__(self, underlying_exception):
         # just put the contextual representation of the error to hint on what
         # went wrong without exposing internals
-        super(MarshallingError, self).__init__(text_type(underlying_exception))
+        super(MarshallingError, self).__init__(str(underlying_exception))
 
 
 def is_indexable_but_not_string(obj):
@@ -138,6 +134,9 @@ class Raw(object):
     :param bool readonly: Is the field read only ? (for documentation purpose)
     :param example: An optional data example (for documentation purpose)
     :param callable mask: An optional mask function to be applied to output
+    :param bool nullable: Whether the field accepts null values in input
+        validation. When True, the generated JSON Schema will allow null
+        values for this field during request payload validation.
     """
 
     #: The JSON/Swagger schema type
@@ -157,6 +156,7 @@ class Raw(object):
         readonly=None,
         example=None,
         mask=None,
+        nullable=None,
         **kwargs
     ):
         self.attribute = attribute
@@ -167,6 +167,7 @@ class Raw(object):
         self.readonly = readonly
         self.example = example if example is not None else self.__schema_example__
         self.mask = mask
+        self.nullable = nullable
 
     def format(self, value):
         """
@@ -288,6 +289,19 @@ class Nested(Raw):
             schema["allOf"] = allOf
         else:
             schema["$ref"] = ref
+
+        # If nullable is True, wrap using anyOf to permit nulls for input validation
+        if self.nullable:
+            # Remove structural keys that conflict with anyOf composition
+            for key in ("$ref", "allOf", "type", "items"):
+                schema.pop(key, None)
+            # Create anyOf with the original schema and null type
+            anyOf = [{"$ref": ref}]
+            if self.as_list:
+                anyOf = [{"type": "array", "items": {"$ref": ref}}]
+            anyOf.append({"type": "null"})
+            schema["anyOf"] = anyOf
+
         return schema
 
     def clone(self, mask=None):
@@ -337,9 +351,11 @@ class List(Raw):
         return [
             self.container.output(
                 idx,
-                val
-                if (isinstance(val, dict) or is_attr(val)) and not is_nested
-                else value,
+                (
+                    val
+                    if (isinstance(val, dict) or is_attr(val)) and not is_nested
+                    else value
+                ),
             )
             for idx, val in enumerate(value)
         ]
@@ -427,9 +443,7 @@ class NumberMixin(MinMaxMixin):
 
 class String(StringMixin, Raw):
     """
-    Marshal a value as a string. Uses ``six.text_type`` so values will
-    be converted to :class:`unicode` in python2 and :class:`str` in
-    python3.
+    Marshal a value as a string.
     """
 
     def __init__(self, *args, **kwargs):
@@ -440,7 +454,7 @@ class String(StringMixin, Raw):
 
     def format(self, value):
         try:
-            return text_type(value)
+            return str(value)
         except ValueError as ve:
             raise MarshallingError(ve)
 
@@ -496,7 +510,7 @@ class Arbitrary(NumberMixin, Raw):
     """
 
     def format(self, value):
-        return text_type(Decimal(value))
+        return str(Decimal(value))
 
 
 ZERO = Decimal()
@@ -515,7 +529,7 @@ class Fixed(NumberMixin, Raw):
         dvalue = Decimal(value)
         if not dvalue.is_normal() and dvalue != ZERO:
             raise MarshallingError("Invalid Fixed precision number.")
-        return text_type(dvalue.quantize(self.precision, rounding=ROUND_HALF_EVEN))
+        return str(dvalue.quantize(self.precision, rounding=ROUND_HALF_EVEN))
 
 
 class Boolean(Raw):
@@ -552,7 +566,7 @@ class DateTime(MinMaxMixin, Raw):
     def parse(self, value):
         if value is None:
             return None
-        elif isinstance(value, string_types):
+        elif isinstance(value, str):
             parser = (
                 datetime_from_iso8601
                 if self.dt_format == "iso8601"
@@ -624,7 +638,7 @@ class Date(DateTime):
     def parse(self, value):
         if value is None:
             return None
-        elif isinstance(value, string_types):
+        elif isinstance(value, str):
             return date_from_iso8601(value)
         elif isinstance(value, datetime):
             return value.date()
@@ -685,7 +699,7 @@ class FormattedString(StringMixin, Raw):
 
     def __init__(self, src_str, **kwargs):
         super(FormattedString, self).__init__(**kwargs)
-        self.src_str = text_type(src_str)
+        self.src_str = str(src_str)
 
     def output(self, key, obj, **kwargs):
         try:
@@ -735,7 +749,7 @@ class Polymorph(Nested):
 
     def __init__(self, mapping, required=False, **kwargs):
         self.mapping = mapping
-        parent = self.resolve_ancestor(list(itervalues(mapping)))
+        parent = self.resolve_ancestor(list(mapping.values()))
         super(Polymorph, self).__init__(parent, allow_null=not required, **kwargs)
 
     def output(self, key, obj, ordered=False, **kwargs):
@@ -752,7 +766,7 @@ class Polymorph(Nested):
             raise ValueError("Polymorph field only accept class instances")
 
         candidates = [
-            fields for cls, fields in iteritems(self.mapping) if type(value) == cls
+            fields for cls, fields in self.mapping.items() if type(value) == cls
         ]
 
         if len(candidates) <= 0:
@@ -825,7 +839,7 @@ class Wildcard(Raw):
         if obj == self._obj and self._flat is not None:
             return self._flat
         if isinstance(obj, dict):
-            self._flat = [x for x in iteritems(obj)]
+            self._flat = [x for x in obj.items()]
         else:
 
             def __match_attributes(attribute):
