@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This module provide some helpers for advanced types parsing.
 
@@ -16,21 +15,19 @@ You can define you own parser using the same pattern:
 
 The last line allows you to document properly the type in the Swagger documentation.
 """
-from __future__ import unicode_literals
 
 import re
 import socket
 
-from datetime import datetime, time, timedelta
+from datetime import datetime, time, timedelta, timezone
 from email.utils import parsedate_tz, mktime_tz
-from six.moves.urllib.parse import urlparse
+from urllib.parse import urlparse
 
 import aniso8601
-import pytz
 
 # Constants for upgrading date-based intervals to full datetimes.
-START_OF_DAY = time(0, 0, 0, tzinfo=pytz.UTC)
-END_OF_DAY = time(23, 59, 59, 999999, tzinfo=pytz.UTC)
+START_OF_DAY = time(0, 0, 0, tzinfo=timezone.utc)
+END_OF_DAY = time(23, 59, 59, 999999, tzinfo=timezone.utc)
 
 
 netloc_regex = re.compile(
@@ -340,11 +337,11 @@ def _normalize_interval(start, end, value):
         end = datetime.combine(end, START_OF_DAY)
 
     if start.tzinfo is None:
-        start = pytz.UTC.localize(start)
-        end = pytz.UTC.localize(end)
+        start = start.replace(tzinfo=timezone.utc)
+        end = end.replace(tzinfo=timezone.utc)
     else:
-        start = start.astimezone(pytz.UTC)
-        end = end.astimezone(pytz.UTC)
+        start = start.astimezone(timezone.utc)
+        end = end.astimezone(timezone.utc)
 
     return start, end
 
@@ -426,11 +423,11 @@ def iso8601interval(value, argument="argument"):
 
         start, end = _normalize_interval(start, end, value)
 
-    except ValueError:
+    except ValueError as e:
         msg = (
             "Invalid {arg}: {value}. {arg} must be a valid ISO8601 date/time interval."
         )
-        raise ValueError(msg.format(arg=argument, value=value))
+        raise ValueError(msg.format(arg=argument, value=value)) from e
 
     return start, end
 
@@ -523,9 +520,16 @@ def boolean(value):
     elif not value:
         return False
     value = str(value).lower()
-    if value in ("true", "1", "on",):
+    if value in (
+        "true",
+        "1",
+        "on",
+    ):
         return True
-    if value in ("false", "0",):
+    if value in (
+        "false",
+        "0",
+    ):
         return False
     raise ValueError("Invalid literal for boolean(): {0}".format(value))
 
@@ -554,9 +558,9 @@ def datetime_from_rfc822(value):
         timetuple = parsedate_tz(value)
         timestamp = mktime_tz(timetuple)
         if timetuple[-1] is None:
-            return datetime.fromtimestamp(timestamp).replace(tzinfo=pytz.utc)
+            return datetime.fromtimestamp(timestamp).replace(tzinfo=timezone.utc)
         else:
-            return datetime.fromtimestamp(timestamp, pytz.utc)
+            return datetime.fromtimestamp(timestamp, timezone.utc)
     except Exception:
         raise ValueError('Invalid date literal "{0}"'.format(raw))
 
