@@ -1,24 +1,17 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import copy
 import re
 import warnings
 
 from collections import OrderedDict
 
-try:
-    from collections.abc import MutableMapping
-except ImportError:
-    # TODO Remove this to drop Python2 support
-    from collections import MutableMapping
-from six import iteritems, itervalues
+from collections.abc import MutableMapping
 from werkzeug.utils import cached_property
 
 from .mask import Mask
 from .errors import abort
 
 from jsonschema import Draft4Validator
+from jsonschema.validators import validator_for
 from jsonschema.exceptions import ValidationError
 
 from .utils import not_none
@@ -97,9 +90,48 @@ class ModelBase(object):
         return model
 
     def validate(self, data, resolver=None, format_checker=None):
-        validator = Draft4Validator(
-            self.__schema__, resolver=resolver, format_checker=format_checker
-        )
+        # For backward compatibility, resolver can be either a RefResolver or a Registry
+        if resolver is not None and hasattr(resolver, "resolve"):
+            # Old RefResolver - convert to registry
+            registry = None
+            validator = Draft4Validator(
+                self.__schema__, resolver=resolver, format_checker=format_checker
+            )
+        else:
+            # New Registry or None
+            # If we have a registry, we need to create a schema that includes definitions
+            schema_to_validate = self.__schema__
+            if resolver is not None:
+                # Check if the schema has $ref that need to be resolved
+                import json
+
+                schema_str = json.dumps(self.__schema__)
+                if '"$ref"' in schema_str:
+                    # Create a schema with inline definitions from the registry
+                    definitions = {}
+                    for uri in resolver:
+                        resource = resolver[uri]
+                        if isinstance(resource, dict) and "definitions" in resource:
+                            definitions.update(resource["definitions"])
+
+                    if definitions:
+                        # Create a new schema that includes the definitions
+                        schema_to_validate = {
+                            "$id": "http://localhost/schema.json",
+                            "definitions": definitions,
+                            **self.__schema__,
+                        }
+
+            ValidatorClass = validator_for(schema_to_validate)
+            if resolver is not None:
+                validator = ValidatorClass(
+                    schema_to_validate, registry=resolver, format_checker=format_checker
+                )
+            else:
+                validator = ValidatorClass(
+                    schema_to_validate, format_checker=format_checker
+                )
+
         try:
             validator.validate(data)
         except ValidationError:
@@ -154,7 +186,7 @@ class RawModel(ModelBase):
         properties = self.wrapper()
         required = set()
         discriminator = None
-        for name, field in iteritems(self):
+        for name, field in self.items():
             field = instance(field)
             properties[name] = field.__schema__
             if field.required:
@@ -171,7 +203,7 @@ class RawModel(ModelBase):
         }
 
         if self.__strict__:
-            definition['additionalProperties'] = False
+            definition["additionalProperties"] = False
 
         return not_none(definition)
 
@@ -188,9 +220,7 @@ class RawModel(ModelBase):
             resolved.update(parent.resolved)
 
         # Handle discriminator
-        candidates = [
-            f for f in itervalues(resolved) if getattr(f, "discriminator", None)
-        ]
+        candidates = [f for f in resolved.values() if getattr(f, "discriminator", None)]
         # Ensure the is only one discriminator
         if len(candidates) > 1:
             raise ValueError("There can only be one discriminator by schema")
@@ -243,7 +273,7 @@ class RawModel(ModelBase):
     def __deepcopy__(self, memo):
         obj = self.__class__(
             self.name,
-            [(key, copy.deepcopy(value, memo)) for key, value in iteritems(self)],
+            [(key, copy.deepcopy(value, memo)) for key, value in self.items()],
             mask=self.__mask__,
             strict=self.__strict__,
         )
