@@ -1,8 +1,7 @@
 import re
-import pytz
 import pytest
 
-from datetime import date, datetime
+from datetime import date, datetime, timezone
 
 from flask_restx import inputs
 
@@ -37,18 +36,18 @@ class Iso8601DatetimeTest(object):
         "value,expected",
         [
             ("2011-01-01", datetime(2011, 1, 1)),
-            ("2011-01-01T00:00:00+00:00", datetime(2011, 1, 1, tzinfo=pytz.utc)),
+            ("2011-01-01T00:00:00+00:00", datetime(2011, 1, 1, tzinfo=timezone.utc)),
             (
                 "2011-01-01T23:59:59+00:00",
-                datetime(2011, 1, 1, 23, 59, 59, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 23, 59, 59, tzinfo=timezone.utc),
             ),
             (
                 "2011-01-01T23:59:59.001000+00:00",
-                datetime(2011, 1, 1, 23, 59, 59, 1000, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 23, 59, 59, 1000, tzinfo=timezone.utc),
             ),
             (
                 "2011-01-01T23:59:59+02:00",
-                datetime(2011, 1, 1, 21, 59, 59, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 21, 59, 59, tzinfo=timezone.utc),
             ),
         ],
     )
@@ -70,22 +69,28 @@ class Rfc822DatetimeTest(object):
     @pytest.mark.parametrize(
         "value,expected",
         [
-            ("Sat, 01 Jan 2011", datetime(2011, 1, 1, tzinfo=pytz.utc)),
-            ("Sat, 01 Jan 2011 00:00", datetime(2011, 1, 1, tzinfo=pytz.utc)),
-            ("Sat, 01 Jan 2011 00:00:00", datetime(2011, 1, 1, tzinfo=pytz.utc)),
-            ("Sat, 01 Jan 2011 00:00:00 +0000", datetime(2011, 1, 1, tzinfo=pytz.utc)),
-            ("Sat, 01 Jan 2011 00:00:00 -0000", datetime(2011, 1, 1, tzinfo=pytz.utc)),
+            ("Sat, 01 Jan 2011", datetime(2011, 1, 1, tzinfo=timezone.utc)),
+            ("Sat, 01 Jan 2011 00:00", datetime(2011, 1, 1, tzinfo=timezone.utc)),
+            ("Sat, 01 Jan 2011 00:00:00", datetime(2011, 1, 1, tzinfo=timezone.utc)),
+            (
+                "Sat, 01 Jan 2011 00:00:00 +0000",
+                datetime(2011, 1, 1, tzinfo=timezone.utc),
+            ),
+            (
+                "Sat, 01 Jan 2011 00:00:00 -0000",
+                datetime(2011, 1, 1, tzinfo=timezone.utc),
+            ),
             (
                 "Sat, 01 Jan 2011 23:59:59 -0000",
-                datetime(2011, 1, 1, 23, 59, 59, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 23, 59, 59, tzinfo=timezone.utc),
             ),
             (
                 "Sat, 01 Jan 2011 21:00:00 +0200",
-                datetime(2011, 1, 1, 19, 0, 0, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 19, 0, 0, tzinfo=timezone.utc),
             ),
             (
                 "Sat, 01 Jan 2011 21:00:00 -0200",
-                datetime(2011, 1, 1, 23, 0, 0, tzinfo=pytz.utc),
+                datetime(2011, 1, 1, 23, 0, 0, tzinfo=timezone.utc),
             ),
         ],
     )
@@ -653,7 +658,7 @@ class EmailTest(object):
     @pytest.mark.parametrize(
         "value",
         [
-            "coucou@not-found.fr",
+            "coucou@not-found.test",
             "me@localhost",
             "me@127.0.0.1",
             "me@127.1.2.3",
@@ -985,136 +990,136 @@ interval_test_values = [
         # Full precision with explicit UTC.
         "2013-01-01T12:30:00Z/P1Y2M3DT4H5M6S",
         (
-            datetime(2013, 1, 1, 12, 30, 0, tzinfo=pytz.utc),
-            datetime(2014, 3, 5, 16, 35, 6, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, 0, tzinfo=timezone.utc),
+            datetime(2014, 3, 5, 16, 35, 6, tzinfo=timezone.utc),
         ),
     ),
     (
         # Full precision with alternate UTC indication
         "2013-01-01T12:30+00:00/P2D",
         (
-            datetime(2013, 1, 1, 12, 30, 0, tzinfo=pytz.utc),
-            datetime(2013, 1, 3, 12, 30, 0, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, 0, tzinfo=timezone.utc),
+            datetime(2013, 1, 3, 12, 30, 0, tzinfo=timezone.utc),
         ),
     ),
     (
         # Implicit UTC with time
         "2013-01-01T15:00/P1M",
         (
-            datetime(2013, 1, 1, 15, 0, 0, tzinfo=pytz.utc),
-            datetime(2013, 1, 31, 15, 0, 0, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 15, 0, 0, tzinfo=timezone.utc),
+            datetime(2013, 1, 31, 15, 0, 0, tzinfo=timezone.utc),
         ),
     ),
     (
         # TZ conversion
         "2013-01-01T17:00-05:00/P2W",
         (
-            datetime(2013, 1, 1, 22, 0, 0, tzinfo=pytz.utc),
-            datetime(2013, 1, 15, 22, 0, 0, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 22, 0, 0, tzinfo=timezone.utc),
+            datetime(2013, 1, 15, 22, 0, 0, tzinfo=timezone.utc),
         ),
     ),
     (
         # Date upgrade to midnight-midnight period
         "2013-01-01/P3D",
         (
-            datetime(2013, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-            datetime(2013, 1, 4, 0, 0, 0, 0, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 0, 0, 0, tzinfo=timezone.utc),
+            datetime(2013, 1, 4, 0, 0, 0, 0, tzinfo=timezone.utc),
         ),
     ),
     (
         # Start/end with UTC
         "2013-01-01T12:00:00Z/2013-02-01T12:00:00Z",
         (
-            datetime(2013, 1, 1, 12, 0, 0, tzinfo=pytz.utc),
-            datetime(2013, 2, 1, 12, 0, 0, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 0, 0, tzinfo=timezone.utc),
+            datetime(2013, 2, 1, 12, 0, 0, tzinfo=timezone.utc),
         ),
     ),
     (
         # Start/end with time upgrade
         "2013-01-01/2013-06-30",
         (
-            datetime(2013, 1, 1, tzinfo=pytz.utc),
-            datetime(2013, 6, 30, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, tzinfo=timezone.utc),
+            datetime(2013, 6, 30, tzinfo=timezone.utc),
         ),
     ),
     (
         # Start/end with TZ conversion
         "2013-02-17T12:00:00-07:00/2013-02-28T15:00:00-07:00",
         (
-            datetime(2013, 2, 17, 19, 0, 0, tzinfo=pytz.utc),
-            datetime(2013, 2, 28, 22, 0, 0, tzinfo=pytz.utc),
+            datetime(2013, 2, 17, 19, 0, 0, tzinfo=timezone.utc),
+            datetime(2013, 2, 28, 22, 0, 0, tzinfo=timezone.utc),
         ),
     ),
     (  # Resolution expansion for single date(time)
         # Second with UTC
         "2013-01-01T12:30:45Z",
         (
-            datetime(2013, 1, 1, 12, 30, 45, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 12, 30, 46, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, 45, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 12, 30, 46, tzinfo=timezone.utc),
         ),
     ),
     (
         # Second with tz conversion
         "2013-01-01T12:30:45+02:00",
         (
-            datetime(2013, 1, 1, 10, 30, 45, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 10, 30, 46, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 10, 30, 45, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 10, 30, 46, tzinfo=timezone.utc),
         ),
     ),
     (
         # Second with implicit UTC
         "2013-01-01T12:30:45",
         (
-            datetime(2013, 1, 1, 12, 30, 45, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 12, 30, 46, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, 45, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 12, 30, 46, tzinfo=timezone.utc),
         ),
     ),
     (
         # Minute with UTC
         "2013-01-01T12:30+00:00",
         (
-            datetime(2013, 1, 1, 12, 30, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 12, 31, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 12, 31, tzinfo=timezone.utc),
         ),
     ),
     (
         # Minute with conversion
         "2013-01-01T12:30+04:00",
         (
-            datetime(2013, 1, 1, 8, 30, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 8, 31, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 8, 30, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 8, 31, tzinfo=timezone.utc),
         ),
     ),
     (
         # Minute with implicit UTC
         "2013-01-01T12:30",
         (
-            datetime(2013, 1, 1, 12, 30, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 12, 31, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, 30, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 12, 31, tzinfo=timezone.utc),
         ),
     ),
     (
         # Hour, explicit UTC
         "2013-01-01T12Z",
         (
-            datetime(2013, 1, 1, 12, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 13, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 13, tzinfo=timezone.utc),
         ),
     ),
     (
         # Hour with offset
         "2013-01-01T12-07:00",
         (
-            datetime(2013, 1, 1, 19, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 20, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 19, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 20, tzinfo=timezone.utc),
         ),
     ),
     (
         # Hour with implicit UTC
         "2013-01-01T12",
         (
-            datetime(2013, 1, 1, 12, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 13, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 13, tzinfo=timezone.utc),
         ),
     ),
     (
@@ -1122,8 +1127,8 @@ interval_test_values = [
         # be accepted.
         "2013-01-01T12:00:00.0/2013-01-01T12:30:00.000000",
         (
-            datetime(2013, 1, 1, 12, tzinfo=pytz.utc),
-            datetime(2013, 1, 1, 12, 30, tzinfo=pytz.utc),
+            datetime(2013, 1, 1, 12, tzinfo=timezone.utc),
+            datetime(2013, 1, 1, 12, 30, tzinfo=timezone.utc),
         ),
     ),
 ]
